@@ -2,9 +2,11 @@ import collections
 import logging
 import sys
 
-import yaml
-
 from .errors import ShowNotInConfigException
+if sys.version_info[0] == 3:
+    from .vendor import yaml
+else:
+    from .vendor import yaml2 as yaml
 
 
 class Config(object):
@@ -57,7 +59,7 @@ class Config(object):
         try:
             with open(config, 'r') as f:
                 return yaml.safe_load(f)
-        except yaml.YAMLError as e:
+        except yaml.error.YAMLError as e:
             self.log.critical(e)
             print('')
             print('-' * 79)
