@@ -2,15 +2,17 @@ from __future__ import unicode_literals
 import logging
 import os
 import urllib
-from xml.etree.ElementTree import fromstring
-try:  # XML Exception class import dance
-    from xml.etree.ElementTree import ParseError
-except ImportError:  # python 2.6
-    from xml.parsers.expat import ExpatError as ParseError
+try:
+    from .vendor.defusedxml.ElementTree import ParseError
+except ImportError:  # python 2
+    try:
+        from xml.etree.ElementTree import ParseError
+    except ImportError:  # python 2.6
+        from xml.parsers.expat import ExpatError as ParseError
 
-import requests
-
-from .import errors
+from . import errors
+from .vendor import requests
+from .vendor.defusedxml.ElementTree import fromstring
 
 
 class BaseLibrary(object):
