@@ -251,7 +251,7 @@ class TvRenamr(object):
 
         return show_name
 
-    def build_path(self, _file, rename_dir=None, organise=None):
+    def build_path(self, _file, rename_dir=None, organise=None, specials_folder=None):
         """Build the full destination path and filename of the renamed file.
 
         By default the format is:
@@ -271,7 +271,7 @@ class TvRenamr(object):
         if organise is None:
             organise = self.config.get(_file.show_name, 'organise')
         if organise is True:
-            args = [rename_dir, _file.show_name, _file.season]
+            args = [rename_dir, _file.show_name, _file.season, specials_folder]
             rename_dir = self._build_organise_path(*args)
 
         log.log(22, 'Directory: {0}'.format(rename_dir))
@@ -330,18 +330,22 @@ class TvRenamr(object):
         log.debug('Filename yielded: {0}'.format(msg))
         return details
 
-    def _build_organise_path(self, start_path, show_name, season_number):
-        """Constructs a directory path using the show's details.
+    def _build_organise_path(self, start_path, show_name, season_number, specials=None):
+        """
+        Constructs a directory path using the show's details.
 
         Show name and season number of an episode dictate the folder structure.
-
         """
-        if start_path[-1:] != '/':
-            start_path = start_path + '/'
-        path = start_path + show_name + '/Season ' + str(int(season_number)) + '/'
-        if not os.path.exists(path) and not self.dry and not self.debug:
+        season = 'Season {0}'.format(season_number)
+        if season_number is 0:  # specials folder
+            season = specials or self.config.get(show_name, 'specials_folder')
+
+        path = os.path.join(start_path, show_name, season)
+
+        if not (os.path.exists(path) or self.dry or self.debug):
             os.makedirs(path)
             log.debug('Directories created for path: ' + path)
+
         return path
 
     def _build_regex(self, regex=None, partial=False):
